%global with_systemd 0%{?fedora} >= 17 || 0%{?rhel} >= 7 
%global shinken_user nagios
%global shinken_group nagios

Summary:        Python Monitoring tool
Name:           shinken
Version:        2.4.2
Release:        2%{?dist}
URL:            http://www.%{name}-monitoring.org
Source0:        https://github.com/naparuba/%{name}/archive/%{version}.tar.gz 
Source1:        %{name}.8shinken
Source2:       	path.cfg
Source3:       	%{name}-arbiter.service 
Source4:       	%{name}-broker.service 
Source5:       	%{name}-reactionner.service 
Source6:       	%{name}-receiver.service 
Source7:       	%{name}-poller.service 
Source8:       	%{name}-scheduler.service 
License:        AGPLv3+
Requires:       python-simplejson 
Requires:       python-pycurl  
Requires:       python-cherrypy 
%if %{with_systemd}
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
%else
Requires(post):  chkconfig
Requires(preun): chkconfig
# This is for /sbin/service
Requires(preun): initscripts
%endif
BuildRequires:  python-devel
BuildRequires:  python-setuptools
%if %{with_systemd}
BuildRequires:  systemd-units
%endif

BuildRoot:      %{_tmppath}/%{name}-%{version}-buildroot
Buildarch:      noarch

%description 
Shinken is a new monitoring tool written in Python. 
The main goal of Shinken is to allow users to have a fully flexible 
architecture for their monitoring system that can easily scale to large 
environments.
Shinken also provide interfaces with NDODB and Merlin database, 
Livestatus connector Shinken does not include any human interfaces.

%package arbiter
Summary: Shinken Arbiter 
Requires: %{name} = %{version}-%{release}

%description arbiter
Shinken arbiter daemon

%package reactionner
Summary: Shinken Reactionner
Requires: %{name} = %{version}-%{release}

%description reactionner
Shinken reactionner daemon

%package scheduler
Summary: Shinken Scheduler
Requires: %{name} = %{version}-%{release}

%description scheduler
Shinken scheduler daemon

%package poller
Summary: Shinken Poller
Requires: %{name} = %{version}-%{release}
Requires: nagios-plugins-all

%description poller
Shinken poller daemon

%package broker
Summary: Shinken Broker
Requires: %{name} = %{version}-%{release}

%description broker
Shinken broker daemon

%package receiver
Summary: Shinken Poller
Requires: %{name} = %{version}-%{release}

%description receiver
Shinken receiver daemon

%prep

%setup -q -n %{name}-%{version}


# clean git files/
find . -name '.gitignore' -exec rm -f {} \;
find . -name '.gitempty' -exec rm -f {} \;
find . -name '.gitkeep' -exec rm -f {} \;

# Check confuguration files 
sed -i -e 's!./$SCRIPT!python ./$SCRIPT!' test/quick_tests.sh
sed -i -e 's!include var/void_for_git!exclude var/void_for_git!'  MANIFEST.in

%build

%{__python} setup.py  build 

%install

find %{buildroot} -size 0 -delete

%{__python} setup.py install -O1 --root %{buildroot} --install-scripts=/usr/sbin/ --owner %{shinken_user} --group %{shinken_group}

install -d -m0755 %{buildroot}%{_sbindir}
install -p -m0755 bin/shinken-{arbiter,broker,poller,reactionner,receiver,scheduler} %{buildroot}%{_sbindir}

install -d -m0755 %{buildroot}%{python_sitelib}/%{name}
install -p %{name}/*.py %{buildroot}%{python_sitelib}/%{name}

install -d -m0755 %{buildroot}%{_sysconfdir}/%{name}/
rm -rf %{buildroot}%{_sysconfdir}/%{name}/*

install -d -m0755 %{buildroot}%{_sysconfdir}/%{name}/daemons
install -p -m0644 etc/daemons/{brokerd,pollerd,reactionnerd,receiverd,schedulerd}.ini %{buildroot}%{_sysconfdir}/%{name}/daemons/

install -d -m0755 %{buildroot}%{_sysconfdir}/%{name}/{arbiters,brokers,pollers,schedulers,reactionners,receivers}
install -p -m0644 etc/arbiters/arbiter-master.cfg %{buildroot}%{_sysconfdir}/%{name}/arbiters/
install -p -m0644 etc/brokers/broker-master.cfg %{buildroot}%{_sysconfdir}/%{name}/brokers/
install -p -m0644 etc/pollers/poller-master.cfg %{buildroot}%{_sysconfdir}/%{name}/pollers/
install -p -m0644 etc/reactionners/reactionner-master.cfg %{buildroot}%{_sysconfdir}/%{name}/reactionners/
install -p -m0644 etc/receivers/receiver-master.cfg %{buildroot}%{_sysconfdir}/%{name}/receivers/
install -p -m0644 etc/schedulers/scheduler-master.cfg %{buildroot}%{_sysconfdir}/%{name}/schedulers/

install -p -m0644 etc/%{name}.cfg %{buildroot}%{_sysconfdir}/%{name}/%{name}.cfg
install -d -m0755 %{buildroot}%{_sysconfdir}/%{name}/{commands,timeperiods,escalations,dependencies,templates,notificationways,servicegroups,hostgroups,contactgroups,hosts,services,contacts,packs,modules,realms,resource.d}

install -p -m0644 etc/realms/all.cfg %{buildroot}%{_sysconfdir}/%{name}/realms/
install -p -m0644 for_fedora/etc/templates.cfg %{buildroot}%{_sysconfdir}/%{name}/templates/
install -p -m0644 for_fedora/etc/timeperiods.cfg %{buildroot}%{_sysconfdir}/%{name}/timeperiods/
install -p -m0644 for_fedora/etc/contactgroups.cfg %{buildroot}%{_sysconfdir}/%{name}/contactgroups/
install -p -m0644 for_fedora/etc/commands.cfg %{buildroot}%{_sysconfdir}/%{name}/commands/
install -p -m0644 for_fedora/etc/objects/contacts/nagiosadmin.cfg %{buildroot}%{_sysconfdir}/%{name}/contacts/nagiosadmin.cfg
install -p -m0644 for_fedora/etc/objects/hosts/localhost.cfg %{buildroot}%{_sysconfdir}/%{name}/hosts/localhost.cfg
install -p -m0644 for_fedora/etc/objects/services/linux_disks.cfg %{buildroot}%{_sysconfdir}/%{name}/services/linux_disks.cfg
install -p -m0644 for_fedora/etc/contactgroups.cfg %{buildroot}%{_sysconfdir}/%{name}/contactgroups/contactgroups.cfg
install -p -m0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/%{name}/resource.d/path.cfg


%if %{with_systemd}
  install -d -m0755 %{buildroot}%{_unitdir}
  install -p -m0644 %{SOURCE3} %{buildroot}%{_unitdir}/%{name}-arbiter.service
  install -p -m0644 %{SOURCE4} %{buildroot}%{_unitdir}/%{name}-broker.service
  install -p -m0644 %{SOURCE5} %{buildroot}%{_unitdir}/%{name}-reactionner.service
  install -p -m0644 %{SOURCE6} %{buildroot}%{_unitdir}/%{name}-receiver.service
  install -p -m0644 %{SOURCE7} %{buildroot}%{_unitdir}/%{name}-poller.service
  install -p -m0644 %{SOURCE8} %{buildroot}%{_unitdir}/%{name}-scheduler.service
%else
  install -d -m0755 %{buildroot}%{_initrddir}
  install -p -m0644 for_fedora/init.d/%{name}-arbiter %{buildroot}%{_initrddir}/%{name}-arbiter
  install -p -m0644 for_fedora/init.d/%{name}-broker %{buildroot}%{_initrddir}/%{name}-broker
  install -p -m0644 for_fedora/init.d/%{name}-reactionner %{buildroot}%{_initrddir}/%{name}-reactionner
  install -p -m0644 for_fedora/init.d/%{name}-scheduler %{buildroot}%{_initrddir}/%{name}-scheduler
  install -p -m0644 for_fedora/init.d/%{name}-receiver %{buildroot}%{_initrddir}/%{name}-receiver
  install -p -m0644 for_fedora/init.d/%{name}-poller %{buildroot}%{_initrddir}/%{name}-poller
%endif

install -d -m0755 %{buildroot}%{_sysconfdir}/logrotate.d
install -p -m0644 for_fedora/%{name}.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

install -d -m0755 %{buildroot}%{_sysconfdir}/tmpfiles.d
install -m0644  for_fedora/%{name}-tmpfiles.conf %{buildroot}%{_sysconfdir}/tmpfiles.d/%{name}.conf

install -d -m0755 %{buildroot}%{_localstatedir}/log/%{name}
install -d -m0755 %{buildroot}%{_localstatedir}/log/%{name}/archives
install -d -m0755 %{buildroot}%{_localstatedir}/lib/%{name}
install -d -m0755 %{buildroot}%{_localstatedir}/lib/%{name}/{share,doc}

mkdir -p %{buildroot}%{_localstatedir}/run/
install -d -m0755 %{buildroot}%{_localstatedir}/run/%{name}

install -d -m0755 %{buildroot}%{_mandir}/man8
install -p -m0644 for_fedora/man/* %{buildroot}%{_mandir}/man8
install -p -m0644 %{SOURCE1} %{buildroot}%{_mandir}/man8


sed -i 's|#!/usr/bin/env python||g' %{buildroot}%{_localstatedir}/lib/%{name}/cli/desc/cli.py
sed -i 's|#!/usr/bin/env python||g' %{buildroot}%{_localstatedir}/lib/%{name}/cli/shinkenio/cli.py
sed -i 's|#!/usr/bin/env python||g' %{buildroot}%{_localstatedir}/lib/%{name}/cli/doc/cli.py

sed -i 's|#!/usr/bin/python||g' %{buildroot}%{_localstatedir}/lib/%{name}/modules/{dummy_arbiter,dummy_broker,dummy_scheduler,dummy_broker_external}/module.py
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{_localstatedir}/lib/%{name}/cli/shinkenio/cli.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{_localstatedir}/lib/%{name}/modules/dummy_poller/module.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{_localstatedir}/lib/%{name}/modules/__init__.py
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{_localstatedir}/lib/%{name}/cli/doc/cli.py

sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/hostextinfo.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/servicegroup.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/serviceescalation.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/hostescalation.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/daemons/reactionnerdaemon.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/clients/livestatus.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/discovery/__init__.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/hostdependency.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/schedulingitem.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/daemons/arbiterdaemon.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/discovery/discoverymanager.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/misc/sorter.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/daemons/brokerdaemon.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/misc/perfdata.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/timeperiod.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/itemgroup.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/daemons/receiverdaemon.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/misc/datamanager.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/hostgroup.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/serviceextinfo.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/__init__.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/resultmodulation.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/misc/__init__.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/contact.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/command.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/config.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/contactgroup.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/pack.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/webui/__init__.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/host.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/businessimpactmodulation.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/escalation.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/clients/LSB.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/realm.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/discoveryrun.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/daemons/schedulerdaemon.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/misc/regenerator.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/clients/__init__.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/discoveryrule.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/service.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/macromodulation.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/checkmodulation.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/matchingitem.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/servicedependency.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/daemons/pollerdaemon.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/daemons/__init__.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/module.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/misc/filter.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/trigger.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/notificationway.py 
sed -i 's|#!/usr/bin/python||g' %{buildroot}%{python_sitelib}/%{name}/objects/item.py 

sed -i 's|#shinken_user=shinken|shinken_user=nagios|g' %{buildroot}%{_sysconfdir}/%{name}/%{name}.cfg
sed -i 's|#shinken_group=shinken|shinken_group=nagios|g' %{buildroot}%{_sysconfdir}/%{name}/%{name}.cfg

sed -i 's|#user=shinken|user=nagios|g' %{buildroot}%{_sysconfdir}/%{name}/daemons/{brokerd,pollerd,reactionnerd,receiverd,schedulerd}.ini
sed -i 's|#group=shinken|group=nagios|g' %{buildroot}%{_sysconfdir}/%{name}/daemons/{brokerd,pollerd,reactionnerd,receiverd,schedulerd}.ini

rm -rf %{buildroot}%{_localstatedir}/lib/%{name}/inventory/__void_for_git
rm -rf %{buildroot}%{_localstatedir}/{log,run,lib}/%{name}/void_for_git
rm -rf %{buildroot}%{_sysconfdir}/init.d/%{name}*
rm -rf %{buildroot}%{_sbindir}/%{name}-{arbiter,discovery,broker,poller,reactionner,receiver,scheduler}.py
rm -rf %{buildroot}%{_sysconfdir}/default/%{name}

rm -rf %{buildroot}%{_localstatedir}/lib/%{name}/libexec
rm -rf %{buildroot}%{_localstatedir}/lib/%{name}/doc

rm -rf  %{buildroot}%{python_sitelib}/modules

find %{buildroot} -maxdepth 5 -name '*.pyc' -exec rm -f {} \;
find %{buildroot} -maxdepth 5 -name '*.pyo' -exec rm -f {} \;

%clean

%pre 
getent group %{shinken_group} >/dev/null || groupadd -r %{shinken_group}
getent passwd %{shinken_user} >/dev/null || useradd -r -g %{shinken_group} -d %{_localstatedir}/spool/nagios -s /sbin/nologin %{shinken_user}
exit 0

%post arbiter
if [ $1 -eq 1 ] ; then 
  %if %{with_systemd}
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
  %else
    /sbin/chkconfig --add %{name}-arbiter || :
  %endif
fi

%post broker
if [ $1 -eq 1 ] ; then 
  %if %{with_systemd}
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
  %else
    /sbin/chkconfig --add %{name}-broker || :
%endif
fi

%post poller
if [ $1 -eq 1 ] ; then 
  %if %{with_systemd}
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
  %else
    /sbin/chkconfig --add %{name}-poller || :
  %endif
fi

%post reactionner
if [ $1 -eq 1 ] ; then 
  %if %{with_systemd}
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
  %else
    /sbin/chkconfig --add %{name}-reactionner || :
%endif
fi

%post scheduler
if [ $1 -eq 1 ] ; then 
  %if %{with_systemd}
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
  %else
    /sbin/chkconfig --add %{name}-scheduler || :
  %endif
fi

%post receiver
if [ $1 -eq 1 ] ; then 
  %if %{with_systemd}
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
  %else
    /sbin/chkconfig --add %{name}-receiver || :
  %endif
fi

%preun arbiter 
if [ $1 -eq 0 ] ; then
  %if %{with_systemd}
    /bin/systemctl --no-reload disable %{name}-arbiter.service > /dev/null 2>&1 || :
    /bin/systemctl stop %{name}-arbiter.service > /dev/null 2>&1 || :
  %else
    /sbin/service %{name}-arbiter stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del %{name}-arbiter || :
  %endif
fi

%preun broker 
if [ $1 -eq 0 ] ; then
  %if %{with_systemd}
    /bin/systemctl --no-reload disable %{name}-broker.service > /dev/null 2>&1 || :
    /bin/systemctl stop %{name}-broker.service > /dev/null 2>&1 || :
  %else
    /sbin/service %{name}-broker stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del %{name}-broker || :
  %endif
fi

%preun poller 
if [ $1 -eq 0 ] ; then
  %if %{with_systemd}
    /bin/systemctl --no-reload disable %{name}-poller.service > /dev/null 2>&1 || :
    /bin/systemctl stop %{name}-poller.service > /dev/null 2>&1 || :
  %else
    /sbin/service %{name}-poller stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del %{name}-poller || :
  %endif
fi

%preun reactionner 
if [ $1 -eq 0 ] ; then
  %if %{with_systemd}
    /bin/systemctl --no-reload disable %{name}-reactionner.service > /dev/null 2>&1 || :
    /bin/systemctl stop %{name}-reactionner.service > /dev/null 2>&1 || :
  %else
    /sbin/service %{name}-reactionner stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del %{name}-reactionner || :
  %endif
fi

%preun scheduler 
if [ $1 -eq 0 ] ; then
  %if %{with_systemd}
    /bin/systemctl --no-reload disable %{name}-scheduler.service > /dev/null 2>&1 || :
    /bin/systemctl stop %{name}-scheduler.service > /dev/null 2>&1 || :
  %else
    /sbin/service %{name}-scheduler stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del %{name}-scheduler || :
  %endif
fi

%preun receiver 
if [ $1 -eq 0 ] ; then
  %if %{with_systemd}
    /bin/systemctl --no-reload disable %{name}-receiver.service > /dev/null 2>&1 || :
    /bin/systemctl stop %{name}-receiver.service > /dev/null 2>&1 || :
  %else
    /sbin/service %{name}-receiver stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del %{name}-receiver || :
  %endif
fi

%postun arbiter
%if %{with_systemd}
  /bin/systemctl daemon-reload >/dev/null 2>&1 || :
  if [ $1 -ge 1 ] ; then
    /bin/systemctl try-restart %{name}-arbiter.service >/dev/null 2>&1 || :
  fi
%endif

%postun broker
%if %{with_systemd}
  /bin/systemctl daemon-reload >/dev/null 2>&1 || :
  if [ $1 -ge 1 ] ; then
    /bin/systemctl try-restart %{name}-broker.service >/dev/null 2>&1 || :
  fi
%endif

%postun poller
%if %{with_systemd}
  /bin/systemctl daemon-reload >/dev/null 2>&1 || :
  if [ $1 -ge 1 ] ; then
    /bin/systemctl try-restart %{name}-poller.service >/dev/null 2>&1 || :
  fi
%endif

%postun reactionner
%if %{with_systemd}
  /bin/systemctl daemon-reload >/dev/null 2>&1 || :
  if [ $1 -ge 1 ] ; then
    /bin/systemctl try-restart %{name}-reactionner.service >/dev/null 2>&1 || :
  fi
%endif

%postun scheduler
%if %{with_systemd}
  /bin/systemctl daemon-reload >/dev/null 2>&1 || :
  if [ $1 -ge 1 ] ; then
    /bin/systemctl try-restart %{name}-scheduler.service >/dev/null 2>&1 || :
  fi
%endif

%postun receiver
%if %{with_systemd}
  /bin/systemctl daemon-reload >/dev/null 2>&1 || :
  if [ $1 -ge 1 ] ; then
    /bin/systemctl try-restart %{name}-receiver.service >/dev/null 2>&1 || :
  fi
%endif

%files arbiter
%if %{with_systemd}
  %{_unitdir}/%{name}-arbiter.service
%else
  %attr(0755,root,root) %{_initrddir}/%{name}-arbiter
%endif
%{_sbindir}/%{name}-arbiter*
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.cfg
%config(noreplace) %{_sysconfdir}/%{name}/arbiters/arbiter-master.cfg
%config(noreplace) %{_sysconfdir}/%{name}/brokers/broker-master.cfg
%config(noreplace) %{_sysconfdir}/%{name}/pollers/poller-master.cfg
%config(noreplace) %{_sysconfdir}/%{name}/reactionners/reactionner-master.cfg
%config(noreplace) %{_sysconfdir}/%{name}/receivers/receiver-master.cfg
%config(noreplace) %{_sysconfdir}/%{name}/schedulers/scheduler-master.cfg
%config(noreplace) %{_sysconfdir}/%{name}/commands/commands.cfg
%config(noreplace) %{_sysconfdir}/%{name}/timeperiods/timeperiods.cfg
%config %{_sysconfdir}/%{name}/escalations
%config %{_sysconfdir}/%{name}/dependencies
%config(noreplace) %{_sysconfdir}/%{name}/templates/templates.cfg
%config %{_sysconfdir}/%{name}/notificationways
%config %{_sysconfdir}/%{name}/servicegroups
%config %{_sysconfdir}/%{name}/hostgroups
%config(noreplace) %{_sysconfdir}/%{name}/contactgroups/contactgroups.cfg
%config(noreplace) %{_sysconfdir}/%{name}/hosts/localhost.cfg
%config(noreplace) %{_sysconfdir}/%{name}/services/linux_disks.cfg
%config(noreplace) %{_sysconfdir}/%{name}/contacts/nagiosadmin.cfg
%config %{_sysconfdir}/%{name}/packs
%config %{_sysconfdir}/%{name}/modules
%config(noreplace) %{_sysconfdir}/%{name}/realms/all.cfg
%config %{_sysconfdir}/%{name}/resource.d

%{_mandir}/man8/%{name}-arbiter*

%files reactionner
%if %{with_systemd}
  %{_unitdir}/%{name}-reactionner.service
%else
  %attr(0755,root,root) %{_initrddir}/%{name}-reactionner
%endif
%{_sbindir}/%{name}-reactionner*
%{_mandir}/man8/%{name}-reactionner*
%config(noreplace) %{_sysconfdir}/%{name}/daemons/reactionnerd.ini

%files scheduler
%if %{with_systemd}
  %{_unitdir}/%{name}-scheduler.service
%else
  %attr(0755,root,root) %{_initrddir}/%{name}-scheduler
%endif
%{_sbindir}/%{name}-scheduler*
%{_mandir}/man8/%{name}-scheduler*
%config(noreplace) %{_sysconfdir}/%{name}/daemons/schedulerd.ini

%files poller
%if %{with_systemd}
  %{_unitdir}/%{name}-poller.service
%else
  %attr(0755,root,root) %{_initrddir}/%{name}-poller
%endif
%{_sbindir}/%{name}-poller*
%{_mandir}/man8/%{name}-poller*
%config(noreplace) %{_sysconfdir}/%{name}/daemons/pollerd.ini

%files broker
%if %{with_systemd}
  %{_unitdir}/%{name}-broker.service
%else
  %attr(0755,root,root) %{_initrddir}/%{name}-broker
%endif
%{_sbindir}/%{name}-broker*
%{_mandir}/man8/%{name}-broker*
%config(noreplace) %{_sysconfdir}/%{name}/daemons/brokerd.ini

%files receiver
%if %{with_systemd}
  %{_unitdir}/%{name}-receiver.service
%else
  %attr(0755,root,root) %{_initrddir}/%{name}-receiver
%endif
%{_sbindir}/%{name}-receiver*
%{_mandir}/man8/%{name}-receiver*
%config(noreplace) %{_sysconfdir}/%{name}/daemons/receiverd.ini

%files
%{python_sitelib}/%{name}
%if %{with_systemd}
%{python_sitelib}/Shinken*.egg-info
%else
%{python_sitelib}/Shinken*.egg-info
%endif
%{_sbindir}/%{name}
%{_sbindir}/%{name}-discovery
%doc COPYING THANKS 
%{_mandir}/man8/%{name}*
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/tmpfiles.d/%{name}.conf
%attr(-,%{shinken_user} ,%{shinken_group}) %dir %{_localstatedir}/log/%{name}
%attr(-,%{shinken_user} ,%{shinken_group}) %{_localstatedir}/lib/%{name}
%attr(-,%{shinken_user} ,%{shinken_group}) %dir %{_localstatedir}/run/%{name}

%changelog
* Fri Dec 4 2015 David Hannequin <david.hannequin@gmail.com> - 2.4.2-2
- subtitute bad user to nagios,
- Add directory. 

* Fri Oct 2 2015 David Hannequin <david.hannequin@gmail.com> - 2.4.2-1
- Update from upstream. 

* Sat Aug 29 2015 David Hannequin <david.hannequin@gmail.com> - 2.4.1-5
- Fix Bug 1257871

* Fri Aug 14 2015 David Hannequin <david.hannequin@gmail.com> - 2.4.1-3
- Fix initial state - Thanks David Durieux

* Fri Jul 24 2015 David Hannequin <david.hannequin@gmail.com> - 2.4.1-1
- Update from upstream.

* Fri Jul 24 2015 David Hannequin <david.hannequin@gmail.com> - 2.2-9
- Fix Bug 1245110 & 1245129.

* Wed Jul 22 2015 David Hannequin <david.hannequin@gmail.com> - 2.2-8
- Delete useless sphinx doc,
- Fix Bug 1245550.

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Jun 2 2015 David Hannequin <david.hannequin@gmail.com> - 2.2-6
- Use init and systemd from upstream.

* Thu May 7 2015 David Hannequin <david.hannequin@gmail.com> - 2.2-4
- Add path.cfg file.

* Fri Mar 27 2015 David Hannequin <david.hannequin@gmail.com> - 2.2-3
- Fix bad daemon configuration file.

* Sun Jan 18 2015 David Hannequin <david.hannequin@gmail.com> - 2.2-2
- Fix Bug 1197485 (thanks Jorge Martínez López).

* Sun Jan 18 2015 David Hannequin <david.hannequin@gmail.com> - 2.2-1
- update from upstream.

* Wed Jul 23 2014 David Hannequin <david.hannequin@gmail.com> - 2.0.3-8
- fix poller init sysV script..

* Wed Jul 23 2014 David Hannequin <david.hannequin@gmail.com> - 2.0.3-7
- Add path.cfg file.

* Wed Jul 23 2014 David Hannequin <david.hannequin@gmail.com> - 2.0.3-6
- Fix init SysV scripts.

* Mon Jul 21 2014 David Hannequin <david.hannequin@gmail.com> - 2.0.3-5
- Add forgot doc dir.

* Fri Jul 18 2014 David Hannequin <david.hannequin@gmail.com> - 2.0.3-4
- Add forgot dir.

* Mon Jul 7 2014 David Hannequin <david.hannequin@gmail.com> - 2.0.3-3
- Add shinken manpage.

* Thu Jul 3 2014 David Hannequin <david.hannequin@gmail.com> - 2.0.3-2
- Delete python mysql require.

* Fri Jun 13 2014 David Hannequin <david.hannequin@gmail.com> - 2.0.3-1
- Update from upstream.

* Fri Apr 25 2014 David Hannequin <david.hannequin@gmail.com> - 2.0.2-1
- Update from upstream.

* Thu Apr 17 2014 David Hannequin <david.hannequin@gmail.com> - 2.0-1
- Update from upstream.

* Sat Mar 01 2014 David Hannequin <david.hannequin@gmail.com> - 1.4.1-2
- bug #1070887 - thank Ignacio Torres Masdeu.

* Thu Jan 02 2014 David Hannequin <david.hannequin@gmail.com> - 1.4.1-1
- Update from upstream.

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon May 27 2013 David Hannequin <david.hannequin@gmail.com> - 1.4-1
- Update from upstream.

* Mon Mar 11 2013 David Hannequin <david.hannequin@gmail.com> - 1.2.4-6
- Fix broker summary.

* Sat Mar 9 2013 David Hannequin <david.hannequin@gmail.com> - 1.2.4-5
- Add Webui menu patch.

* Wed Mar 6 2013 David Hannequin <david.hannequin@gmail.com> - 1.2.4-2
- Fix discovery rules.

* Sun Feb 24 2013 David Hannequin <david.hannequin@gmail.com> - 1.2.4-1
- Update from upstream.

* Wed Jan 30 2013 David Hannequin <david.hannequin@gmail.com> - 1.2.3-1
- Update from upstream.

* Sat Dec 15 2012 David Hannequin <david.hannequin@gmail.com> - 1.2.2-1
- Update from upstream,
- Delete eue module,
- Fix web site url, 
- Fix Bug 874092 (thanks Sébastien Andreatta).

* Fri Dec 14 2012 David Hannequin <david.hannequin@gmail.com> - 1.0.1-7
- Fix uninstall receiver.  

* Mon Nov 5 2012 David Hannequin <david.hannequin@gmail.com> - 1.0.1-6
- Fix bug 874089.  

* Sun Sep 16 2012 David Hannequin <david.hannequin@gmail.com> - 1.0.1-5
- Add support of el6,
- Remove shebang from Python libraries,
- Delete echo printing,
- Remove CFLAGS.

* Mon Sep 10 2012 David Hannequin <david.hannequin@gmail.com> - 1.0.1-4
- Add COPYING README THANKS file,
- delete defattr.

* Sun Sep 09 2012 David Hannequin <david.hannequin@gmail.com> - 1.0.1-3
- Delete require python-sqlite2.

* Sun Jul 22 2012 David Hannequin <david.hannequin@gmail.com> - 1.0.1-2
- Add build patch. 

* Tue Mar 13 2012 David Hannequin <david.hannequin@gmail.com> - 1.0.1-1
- Update from upstream,
- Add shinken packs

* Mon Oct 24 2011 David Hannequin <david.hannequin@gmail.com> - 0.8.1-1
- Update from upstream,
- Add manpage, 
- Add require nagios plugins.  

* Mon May 30 2011 David Hannequin <david.hannequin@gmail.com> - 0.6.5-1
- Update from upstream,
- Add require python-redis, 
- Add require python-memcached.

* Mon May 30 2011 David Hannequin <david.hannequin@gmail.com> - 0.6.4-3
- Fix path in default shinken file,
- Fix path in setup.cfg, 
- Add file FROM_NAGIOS_TO_SHINKEN.

* Sun May 29 2011 David Hannequin <david.hannequin@gmail.com> - 0.6.4-2
- Fix shinken configuration,
- Replace macro,
- Update from upstreamr.

* Fri May 20 2011 David Hannequin <david.hannequin@gmail.com> - 0.6.4-1
- Update from upstream. 

* Fri Apr 29 2011 David Hannequin <david.hannequin@gmail.com> - 0.6-1
- Fisrt release for fedora.
